       

      # def MD(self,nano):
      #     print("self MD")
      #     ##############
      #     import platform 
      #     self.linuex = (False) if (platform.system()=="Windows") else (True)
      #     ### linux 環境
      #     if  self.linuex:   
      #         with open( '/content/cmd.py/README.md' , 'w+' ,encoding='utf-8') as f:
          
      #             ## 寫入
      #             f.seek(0,0) ## 規0
      #             nano=[ i.strip()+'\n' for i in nano.split('\n') ]
      #             f.writelines( nano ) ## 建檔內容

      #     return self  ###########################
      #     ################ 下一個建構子 必須是接收(物件) 